## $Id: viewlets.py 15436 2019-05-29 12:06:23Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##

import grok
from zope.component import getUtility
from waeup.kofa.students.viewlets import (
    AddPreviousPaymentActionButton, AddBalancePaymentActionButton,
    ManageActionButton)
from waeup.kofa.students.interfaces import IStudent, IStudentsUtils
from waeup.kofa.students.browser import StudentBaseDisplayFormPage
from waeup.kofa.students.workflow import (
    ADMITTED, PAID, REQUESTED, RETURNING, CLEARED, REGISTERED,
    VALIDATED, GRADUATED, CREATED, CLEARANCE)
from waeup.kwarapoly.interfaces import MessageFactory as _

class AddPreviousPaymentActionButton(AddPreviousPaymentActionButton):

    @property
    def target_url(self):
        return ''

#class AddBalancePaymentActionButton(AddBalancePaymentActionButton):

#    @property
#    def target_url(self):
#        return ''

class AdmissionNotificationActionButton(ManageActionButton):
    grok.order(4)
    grok.context(IStudent)
    grok.view(StudentBaseDisplayFormPage)
    grok.require('waeup.viewStudent')
    icon = 'actionicon_pdf.png'
    text = _('Download admission notification')
    target = 'admission_notification.pdf'

    @property
    def target_url(self):
        if self.context.state not in (ADMITTED, CLEARANCE, REQUESTED, CLEARED):
            return ''
        return self.view.url(self.view.context, self.target)

class AdmissionSlipActionButton(ManageActionButton):
    grok.order(4)
    grok.context(IStudent)
    grok.view(StudentBaseDisplayFormPage)
    grok.require('waeup.viewStudent')
    icon = 'actionicon_pdf.png'
    text = _('Download admission letter')
    target = 'admission_slip.pdf'

    @property
    def target_url(self):
        if self.context.state in (CREATED, ADMITTED,
                                  CLEARANCE, REQUESTED, CLEARED):
            return ''
        return self.view.url(self.view.context, self.target)

class RegistrationSlipActionButton(ManageActionButton):
    grok.order(4)
    grok.context(IStudent)
    grok.view(StudentBaseDisplayFormPage)
    grok.require('waeup.viewStudent')
    icon = 'actionicon_pdf.png'
    text = _('Download registration form')
    target = 'registration_slip.pdf'

    @property
    def target_url(self):
        if self.context.state in (CREATED,ADMITTED,
                                  CLEARANCE, REQUESTED, CLEARED):
            return ''
        return self.view.url(self.view.context, self.target)


class GetMatricNumberActionButton(ManageActionButton):
    grok.order(10)
    grok.context(IStudent)
    grok.view(StudentBaseDisplayFormPage)
    grok.require('waeup.viewStudent')
    icon = 'actionicon_count.png'
    text = _('Get Matriculation Number')

    @property
    def target_url(self):
        students_utils = getUtility(IStudentsUtils)
        if self.context.matric_number:
            return ''
        error, matric_number = students_utils.constructMatricNumber(
            self.context)
        if error:
            return ''
        return self.view.url(self.view.context, 'get_matric_number')